@@ -3,8 +3,12 @@
 from typing import Callable, MutableMapping, List, Union, Dict
 from abc import ABC
 from copy import copy
+
+import requests
 from pydantic import create_model, BaseModel, Field
 
+from di_registry.registry import RegistryError
+
 
 class YAMLParam:
     def __init__(self,
@@ -184,7 +188,9 @@ class YAMLConfig(ABC):
         for name, params in self.yaml_parameters.items():
             if params.include is False:
                 continue
-            value = getattr(self, name, None) or params.default_value
+            value = getattr(self, name, None)
+            if value is None and params.allow_null_values is False:
+                value = params.default_value
             if params.typecast is not None and value is not None:
                 value = params.typecast(value)
             out[params.kwarg_alias or name] = value
@@ -228,6 +234,21 @@ class YAMLConfig(ABC):
                 '\n'.join(self.get_full_yaml_string_list(**overrides))
             )
 
+    def save_parameters_to_http(self, config_url: str, **overrides):
+        """
+        Saves parameters by sending a PUT request to the given config_url
+        :param config_url: URL of configuration save endpoint (must support PUT)
+        :param overrides: optional overrides for parameter values
+        """
+        config = {**self.get_current_kwargs(), **overrides}
+        try:
+            response = requests.put(config_url, json=config)
+        except requests.ConnectionError:
+            raise RegistryError(f'Cannot save parameters to "{config_url}", error connecting to server')
+
+        if not response.ok:
+            raise RegistryError(f'Cannot save parameters to "{config_url}", response status: {response.status_code}')
+
     def apply_parameters(self, **kwargs):
         """
         Applies parameters to the instance based on key values in the instance. The keywords must match exactly to the
