@@ -4,8 +4,11 @@ from inspect import isclass
 from os import path
 import re
 import json
+
+import requests as requests
 import yaml
 from deepmerge import always_merger
+from requests import JSONDecodeError
 
 FactoryType = Callable[..., Any]
 ConfigurationType = Dict[str, Union[List, Dict[str, Any]]]
@@ -16,6 +19,10 @@ def configure(config: Union[str, ConfigurationType], file_type: Optional[str] =
     Registry.default_registry().configure(config, file_type, ignore_missing)
 
 
+def http_configure(*names: str, ignore_missing: bool = False):
+    Registry.default_registry().http_configure(*names, ignore_missing=ignore_missing)
+
+
 def reconfigure():
     Registry.default_registry().reconfigure()
 
@@ -87,9 +94,18 @@ class Registry:
         if object_name in self.objects:
             self.objects.pop(object_name)
 
+    def registry_configuration(self) -> Dict[str, Any]:
+        config_key = f'{self.CONFIG_META_PREFIX}registry'
+        if config_key not in self.configuration:
+            raise RegistryError(f'Unable to read registry configuration, "{config_key}" not found in configuration')
+
+        return self.configuration[config_key]
+
     def configure(self, config: Union[str, ConfigurationType], file_type: Optional[str] = None, ignore_missing: bool = False, append: bool = True):
         if isinstance(config, dict):
             self.merge_configuration(config)
+        elif isinstance(config, str) and config.startswith(('http://', 'https://')):
+            self.load_http_configuration(config, ignore_missing)
         else:
             self.load_configuration(config, file_type, ignore_missing)
 
@@ -97,6 +113,16 @@ class Registry:
             # track configuration files used so we can reload them
             self.configurations.append(config)
 
+    def http_configure(self, *names: str, ignore_missing: bool = True):
+        registry_config = self.registry_configuration()
+
+        if 'configuration_url' not in registry_config:
+            raise RegistryError(f'Cannot use `http_configure`, "$registry.configuration_url" not available in configuration')
+
+        for name in names:
+            config_url = registry_config['configuration_url'] + '/' + name
+            self.configure(config_url, ignore_missing=ignore_missing)
+
     def reconfigure(self):
         self.configuration = {}
 
@@ -127,6 +153,25 @@ class Registry:
             else:
                 raise RegistryError(f'Invalid config file format, must be "json" or "yaml": {config_type}')
 
+    def load_http_configuration(self, config_url, ignore_missing: bool = False):
+        try:
+            response = requests.get(config_url)
+        except requests.ConnectionError:
+            raise RegistryError(f'Cannot read configuration from "{config_url}", error connecting to server')
+
+        if not response.ok:
+            if response.status_code == 404 and ignore_missing:
+                return
+
+            raise RegistryError(f'Cannot read configuration from "{config_url}", response status: {response.status_code}')
+
+        try:
+            config = response.json()
+        except JSONDecodeError:
+            raise RegistryError(f'Cannot read configuration from "{config_url}", error parsing JSON response')
+
+        self.merge_configuration(config)
+
     def get_object_meta_configuration(self, object_name: str) -> Dict[str, Any]:
         if object_name not in self.configuration:
             return {}
